// 全局控制 Gflower 2025-05-01

/*********************
 * 样式和主题配置
 *********************/
const baseStyles = `
:root {
  --primary-color: #8a2be2;
  --secondary-color: #2d3748;
  --text-color: #f7fafc;
  --bg-color: #1a202c;
  --shadow-light: #2d3748;
  --shadow-dark: #0a0e14;
}

/* 基础样式 */
body {
  background: var(--bg-color);
  font-family: Arial, sans-serif;
  padding: 10px;
  color: var(--text-color);
  margin: 0;
  text-align: justify;
}

.card {
  background: var(--bg-color);
  border-radius: 16px;
  padding: 10px 15px;
  margin-bottom: 10px;
  box-shadow: 8px 8px 16px var(--shadow-dark), 
              -8px -8px 16px var(--shadow-light);
}

.sub-card {
  background: var(--bg-color);
  border-radius: 16px;
  padding: 5px;
  box-shadow: 8px 8px 8px var(--shadow-dark),
              -8px -8px 16px var(--shadow-light);
  max-width: 800px;
  margin-top: 4%;
}

h1, h2, h3 {
  color: var(--primary-color);
  line-height: 20px;
}

pre {
  background: var(--secondary-color);
  padding: 10px;
  border-radius: 8px;
  overflow-x: auto;
}

code {
  font-family: 'Courier New', monospace;
  color: #d63384;
}

.note {
  background: rgba(255, 213, 79, 0.1);
  border-left: 4px solid #ffd54f;
  padding: 12px;
  margin: 10px 0;
}

/* 特殊类 */
.abt {
  color: #fff1ffff;
  text-align: left;
}

.info-grid {
  display: grid;
  grid-template-columns: auto 1fr;
  gap: 8px 16px;
}

.feature-list {
  padding-left: 20px;
}

.feature-item {
  margin-bottom: 8px;
}
`;

const themes = {
  
   default: {
     '--primary-color': '#5e72e4',
    '--secondary-color': '#f7fafc',
    '--text-color': '#2d3748',
    '--bg-color': '#e5e9f2',
    '--shadow-light': '#ffffff',
    '--shadow-dark': '#c1c8d7'  
  },
  dark: {
    '--primary-color': '#8a2be2',
    '--secondary-color': '#ffff48',
    '--text-color': '#ffffff',
    '--bg-color': '#00202c',
    '--shadow-light': '#2d3748',
    '--shadow-dark': '#0a0e14'
},
  blue: {
    '--primary-color': '#3182ce',
    '--secondary-color': '#ebf8ff',
    '--text-color': '#2d3748',
    '--bg-color': '#bee3f8',
    '--shadow-light': '#ebf8ff',
    '--shadow-dark': '#90cdf4'
  },
  green: {
    '--primary-color': '#38a169',
    '--secondary-color': '#f0fff4',
    '--text-color': '#2d3748',
    '--bg-color': '#c6f6d5',
    '--shadow-light': '#f0fff4',
    '--shadow-dark': '#9ae6b4'
  },
  red: {
    '--primary-color': '#e53e3e',
    '--secondary-color': '#fff5f5',
    '--text-color': '#2d3748',
    '--bg-color': '#fed7d7',
    '--shadow-light': '#fff5f5',
    '--shadow-dark': '#feb2b2'
  },
  purple: {
    '--primary-color': '#805ad5',
    '--secondary-color': '#faf5ff',
    '--text-color': '#2d3748',
    '--bg-color': '#e9d8fd',
    '--shadow-light': '#faf5ff',
    '--shadow-dark': '#d6bcfa'
  },
  orange: {
    '--primary-color': '#dd6b20',
    '--secondary-color': '#fffaf0',
    '--text-color': '#2d3748',
    '--bg-color': '#feebc8',
    '--shadow-light': '#fffaf0',
    '--shadow-dark': '#fbd38d'
  },
  teal: {
    '--primary-color': '#319795',
    '--secondary-color': '#e6fffa',
    '--text-color': '#2d3748',
    '--bg-color': '#b2f5ea',
    '--shadow-light': '#e6fffa',
    '--shadow-dark': '#81e6d9'
  },
  pink: {
    '--primary-color': '#d53f8c',
    '--secondary-color': '#fff5f7',
    '--text-color': '#2d3748',
    '--bg-color': '#fed7e2',
    '--shadow-light': '#fff5f7',
    '--shadow-dark': '#fbb6ce'
  },
  brown: {
    '--primary-color': '#975a16',
    '--secondary-color': '#fffaf0',
    '--text-color': '#2d3748',
    '--bg-color': '#e2c79e',
    '--shadow-light': '#fffaf0',
    '--shadow-dark': '#d2b48c'
  }
};

/*********************
 * 样式管理函数
 *********************/
function initStyles() {
  // 主文档样式
  const mainStyle = document.createElement('style');
  mainStyle.id = 'main-styles';
  mainStyle.textContent = baseStyles;
  document.head.appendChild(mainStyle);
  
  // iframe样式占位
  const iframeStyle = document.createElement('style');
  iframeStyle.id = 'iframe-styles';
  document.head.appendChild(iframeStyle);
}

function applyTheme(themeName) {
  const theme = themes[themeName] || themes.default;
  const root = document.documentElement;
  
  Object.entries(theme).forEach(([key, value]) => {
    root.style.setProperty(key, value);
  });
  
  updateIframeStyles();
  localStorage.setItem('theme', themeName);
}

function updateIframeStyles() {
  const iframeStyle = document.getElementById('iframe-styles');
  let css = ':root {';
  
  const styles = getComputedStyle(document.documentElement);
  [
    '--primary-color',
    '--secondary-color',
    '--text-color',
    '--bg-color',
    '--shadow-light',
    '--shadow-dark'
  ].forEach(prop => {
    css += `${prop}: ${styles.getPropertyValue(prop)};`;
  });
  
  css += '}';
  iframeStyle.textContent = css;
  
  // 更新iframe内容
  const iframe = document.getElementById('contentFrame');
  if (iframe && iframe.contentWindow) {
    iframe.contentWindow.postMessage({
      type: 'THEME_UPDATE',
      css: css
    }, '*');
  }
}

// DOM元素
const sidebar = document.getElementById('sidebar');
const sidebarToggle = document.getElementById('sidebarToggle');
const closeSidebar = document.getElementById('closeSidebar');
const mainContent = document.getElementById('mainContent');
const contentFrame = document.getElementById('contentFrame');
const menuItems = document.querySelectorAll('.sidebar-menu a');
const sidebarOverlay = document.getElementById('sidebarOverlay');
const systemInfoHeader = document.getElementById('systemInfoHeader');
const themeOptions = document.querySelectorAll('.theme-options a');

// 模态框元素
const helpModal = document.getElementById('helpModal');
const feedbackModal = document.getElementById('feedbackModal');
const qqGroupModal = document.getElementById('qqGroupModal');
const aboutModal = document.getElementById('aboutModal');

// 初始化加载首页
window.addEventListener('DOMContentLoaded', () => {
    initStyles(); // 初始化样式系统
    loadContent('welcome');
    
    // 初始化折叠菜单
    const collapsibleHeaders = document.querySelectorAll('.collapsible-header');
    collapsibleHeaders.forEach(header => {
        const content = header.nextElementSibling;
        const icon = header.querySelector('.collapse-icon');
        
        // 初始状态为折叠
        content.style.maxHeight = '0';
        header.classList.remove('active');
        
        header.addEventListener('click', (e) => {
            e.stopPropagation();
            header.classList.toggle('active');
            
            if (header.classList.contains('active')) {
                content.classList.add('expanded');
                content.style.maxHeight = content.scrollHeight + 'px';
            } else {
                content.classList.remove('expanded');
                content.style.maxHeight = '0';
            }
        });
    });

    // 系统信息点击返回首页
    systemInfoHeader.addEventListener('click', () => {
        loadContent('welcome');
        systemInfoHeader.style.boxShadow = 'inset 4px 4px 8px var(--shadow-dark), inset -4px -4px 8px var(--shadow-light)';
        setTimeout(() => {
            systemInfoHeader.style.boxShadow = '4px 4px 8px var(--shadow-dark), -4px -4px 8px var(--shadow-light)';
        }, 200);
    });

    // 初始化主题
    const savedTheme = localStorage.getItem('theme') || 'default';
    document.body.setAttribute('data-theme', savedTheme);
    applyTheme(savedTheme);
    
    // 主题下拉菜单控制
    const themeDropdown = document.querySelector('.theme-dropdown');
    const themeOptionsList = document.querySelector('.theme-options');
    
    themeDropdown.addEventListener('click', (e) => {
        e.stopPropagation();
        themeOptionsList.classList.toggle('show');
    });
    
    // 主题选择
    themeOptions.forEach(option => {
        option.addEventListener('click', (e) => {
            e.preventDefault();
            e.stopPropagation();
            const theme = option.getAttribute('data-theme');
            document.body.setAttribute('data-theme', theme);
            applyTheme(theme);
            themeOptionsList.classList.remove('show');
        });
    });
    
    // 点击页面其他位置关闭主题菜单
    document.addEventListener('click', () => {
        themeOptionsList.classList.remove('show');
    });
    
    // 点击模态框外部关闭
    window.addEventListener('click', (e) => {
        if (e.target === helpModal) {
            helpModal.style.display = 'none';
        }
        if (e.target === feedbackModal) {
            feedbackModal.style.display = 'none';
        }
        if (e.target === qqGroupModal) {
            qqGroupModal.style.display = 'none';
        }
        if (e.target === aboutModal) {
            aboutModal.style.display = 'none';
        }
    });
});

// 侧边栏控制
sidebarToggle.addEventListener('click', () => {
    toggleSidebar();
});

closeSidebar.addEventListener('click', () => {
    closeSidebarFunc();
});

sidebarOverlay.addEventListener('click', () => {
    closeSidebarFunc();
});

function toggleSidebar() {
    sidebar.classList.toggle('open');
    mainContent.classList.toggle('shifted');
}

function closeSidebarFunc() {
    sidebar.classList.remove('open');
    mainContent.classList.remove('shifted');
}

// 加载内容函数
function loadContent(section) {
    try {
        // 设置iframe源
        contentFrame.src = `data/${section}.html`;

        // 更新活动菜单项
        updateActiveMenuItem(section);

        // 关闭侧边栏
        closeSidebarFunc();

        // 滚动到顶部
        window.scrollTo({ top: 0, behavior: 'smooth' });
    } catch (error) {
        console.error('加载内容时出错:', error);
        contentFrame.srcdoc = `
            <!DOCTYPE html>
            <html>
            <head>
                <style>
                    body {
                        background: #e5e9f2;
                        font-family: Arial, sans-serif;
                        padding: 40px;
                        text-align: center;
                        color: #e74c3c;
                    }
                </style>
            </head>
            <body>
                <h2>加载内容时出错</h2>
                <p>无法加载请求的内容。请检查：</p>
                <p>1. 文件 data/${section}.html 是否存在</p>
                <p>2. 是否使用了本地服务器运行</p>
                <button onclick="window.location.reload()">刷新页面</button>
            </body>
            </html>
        `;
    }
}

// 更新活动菜单项
function updateActiveMenuItem(section) {
    menuItems.forEach(item => {
        item.classList.remove('active');
        if (item.getAttribute('data-section') === section) {
            item.classList.add('active');
        }
    });
}

// 菜单项点击事件
menuItems.forEach(item => {
    item.addEventListener('click', (e) => {
        e.preventDefault();
        const section = item.getAttribute('data-section');
        loadContent(section);
    });
});

// iframe高度调整
function adjustIframeHeight() {
    try {
        const iframe = document.getElementById('contentFrame');
        if (iframe.contentWindow.document.body) {
            iframe.style.height = iframe.contentWindow.document.body.scrollHeight + 'px';
        }
    } catch (e) {
        console.log('调整高度时出错:', e);
    }
}

// iframe加载完成后调整高度
contentFrame.onload = function() {
    adjustIframeHeight();
    setTimeout(adjustIframeHeight, 500);
};

// 窗口大小改变时调整高度
window.addEventListener('resize', adjustIframeHeight);

// 模态框控制
document.getElementById('helpBtn').addEventListener('click', (e) => {
    e.stopPropagation();
    helpModal.style.display = 'flex';
});

document.getElementById('feedbackBtn').addEventListener('click', (e) => {
    e.stopPropagation();
    feedbackModal.style.display = 'flex';
});

document.getElementById('qqGroupBtn').addEventListener('click', (e) => {
    e.stopPropagation();
    qqGroupModal.style.display = 'flex';
});

document.getElementById('aboutBtn').addEventListener('click', (e) => {
    e.stopPropagation();
    aboutModal.style.display = 'flex';
});

// 关闭模态框
document.getElementById('closeHelpModal').addEventListener('click', () => {
    helpModal.style.display = 'none';
});

document.getElementById('closeFeedbackModal').addEventListener('click', () => {
    feedbackModal.style.display = 'none';
});

document.getElementById('closeQQGroupModal').addEventListener('click', () => {
    qqGroupModal.style.display = 'none';
});

document.getElementById('closeAboutModal').addEventListener('click', () => {
    aboutModal.style.display = 'none';
});